@@ -35,37 +35,35 @@ using namespace bt;
 namespace kt
 {
 
-    WebInterfacePrefWidget::WebInterfacePrefWidget(QWidget* parent)
-        : PrefPageInterface(WebInterfacePluginSettings::self(), i18n("Web Interface"), "network-server", parent)
-    {
-        setupUi(this);
-        connect(kcfg_authentication, &QCheckBox::toggled, this, &WebInterfacePrefWidget::authenticationToggled);
+WebInterfacePrefWidget::WebInterfacePrefWidget(QWidget* parent)
+    : PrefPageInterface(WebInterfacePluginSettings::self(), i18n("Web Interface"), "network-server", parent)
+{
+    setupUi(this);
+    connect(kcfg_authentication, &QCheckBox::toggled, this, &WebInterfacePrefWidget::authenticationToggled);
 
-        QStringList dirList = KGlobal::dirs()->findDirs("data", "ktorrent/www");
-        if (!dirList.isEmpty())
-        {
-            QDir d(*(dirList.begin()));
+    QStringList dirList = KGlobal::dirs()->findDirs("data", "ktorrent/www");
+    if (!dirList.isEmpty()) {
+        QDir d(*(dirList.begin()));
 
-            QStringList skinList = d.entryList(QDir::Dirs);
-            foreach (const QString& skin, skinList)
-            {
-                if (skin == "." || skin == ".." || skin == "common")
-                    continue;
-                kcfg_skin->addItem(skin);
-            }
+        QStringList skinList = d.entryList(QDir::Dirs);
+        foreach (const QString& skin, skinList) {
+            if (skin == "." || skin == ".." || skin == "common")
+                continue;
+            kcfg_skin->addItem(skin);
         }
-        kcfg_username->setEnabled(WebInterfacePluginSettings::authentication());
-        kcfg_password->setEnabled(WebInterfacePluginSettings::authentication());
     }
+    kcfg_username->setEnabled(WebInterfacePluginSettings::authentication());
+    kcfg_password->setEnabled(WebInterfacePluginSettings::authentication());
+}
 
-    WebInterfacePrefWidget::~WebInterfacePrefWidget()
-    {}
+WebInterfacePrefWidget::~WebInterfacePrefWidget()
+{}
 
-    void WebInterfacePrefWidget::authenticationToggled(bool on)
-    {
-        kcfg_username->setEnabled(on);
-        kcfg_password->setEnabled(on);
-    }
+void WebInterfacePrefWidget::authenticationToggled(bool on)
+{
+    kcfg_username->setEnabled(on);
+    kcfg_password->setEnabled(on);
+}
 
 
 }
